@@ -6,6 +6,14 @@ quos = lambda str_iter: ",".join([f"'{s}'" for s in str_iter])
 
 
 def constr(**kwargs):
+    """kwargs
+    ---
+    host: db host address
+    port: db port
+    db_name: db name
+    username: username
+    envfile: envfile path. env 파일을 지정할 경우 kwargs로 입력한 값보다 env에 있는 값을 먼저 적용함.
+    """
     if kwargs.get("envfile"):
         dotenv.load_dotenv(kwargs.get("envfile"))
 
